@@ -41,6 +41,12 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
                        moderators = NULL, cat_moderators = TRUE,
                        moderator_type = c("simple", "hierarchical", "none"),
                        data = NULL, control = control_psychmeta(), ...){
+     
+     .dplyr.show_progress <- options()$dplyr.show_progress
+     .psychmeta.show_progress <- psychmeta.show_progress <- options()$psychmeta.show_progress
+     if(is.null(psychmeta.show_progress)) psychmeta.show_progress <- TRUE
+     options(dplyr.show_progress = psychmeta.show_progress)
+     
      call <- match.call()
      warn_obj1 <- record_warnings()
 
@@ -229,6 +235,10 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
      out <- namelists.ma_psychmeta(ma_obj = out)
      
      class(out) <- c("ma_psychmeta", class(out))
+     
+     options(psychmeta.show_progress = .psychmeta.show_progress)
+     options(dplyr.show_progress = .dplyr.show_progress)
+     
      return(out)
 }
 
